@@ -1,5 +1,7 @@
 from mlapp.managers.user_managers import ModelManager
 from mlapp.managers.user_managers import DataManager
+from mlapp.managers.pipeline_manager import pipeline
 
 __all__ = ('ModelManager',
-           'DataManager')
+           'DataManager',
+           'pipeline')
